@@ -1,7 +1,7 @@
 """Create and manage bundle packages."""
 from __future__ import absolute_import
 
-VERSION = (1, 0, 0)
+VERSION = (1, 1, 1)
 __version__ = ".".join(map(str, VERSION[0:3])) + "".join(VERSION[3:])
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
@@ -10,4 +10,8 @@ __docformat__ = "restructuredtext en"
 
 # -eof meta-
 
-from .bundle import Bundle
+from .bundles import Bundle
+from .extensions import Dist
+from .versions import Version
+
+__all__ = ["Bundle", "Dist", "Version"]
